local cql = ClassicQuestLog

local optInfo = {
    {var="LockWindow", text="Lock Window Position", desc="Prevent dragging the window unless Shift is held."},
    {var="ShowResizeGrip", text="Show Resize Grip", desc="Show a resize grip in the lower-right corner of the window to change its size."},
    {var="PerCharacterPosition", text="Per-Character Window Placement", desc="Remember the window position and size independently for each character."},
    {var="ShowLevels", text="Show Quest Levels", desc="Show the level of each quest in the log."},
    {var="ShowTooltips", text="Show Quest Tooltips", desc="When the mouse is over a quest in the log, show a tooltip of the quest and its progress. Otherwise, holding Shift over a quest in the log will show its tooltip."},
    {var="ShowFromObjectiveTracker", text="Override Objective Tracker", desc="When clicking a quest on the objective tracker (in the default UI, this is the list of quests beneath the minimap), go to the quest in Classic Quest Log instead of the map; unless in combat."},
    {var="ShowFromKeyBind", text="Override Quest Log Key Bind", desc="When the Toggle Quest Log key bind (under Keybindings -> Interface Panel) is pressed, summon Classic Quest Log rather than the default quest log attached to the map. (Under Keybindings -> AddOns you can also set a separate key bind for Classic Quest Log.)"},
    {var="ShowFromMicroButton", text="Override Quest Log Micro Button", desc="When clicking the Quest Log \"micro\" button in the main menu bar, summon Classic Quest Log rather than the default quest log attached to the map."},
    {var="ShowDefaultQuestPortrait", text="Show Default Portraits", desc="When a quest has a portrait to display, show the default popout frame with a model and its related text instead of the portrait in the quest details."},
    {var="ShowMinimapButton", text="Show Minimap Button", desc="Display a movable minimap button to show or hide Classic Quest Log."},
    {var="ShowExtraTypeDetails", text="Show Extra Quest Details", desc="Add whether the quest is account-wide, group, daily, weekly, completed or failed to the top of a quest's details."},
    {var="HideCampaignProgress", text="Hide Campaign Extras", desc="For a more authentic \"classic\" experience, display all quests equally by removing campaign progress and themes."},
    {var="HighContrast", text="High Contrast Mode", desc="Replace the artwork behind the log and quest details to make it easier to read text."},
}

function cql.Options:Setup()
    local content = self.ScrollFrame.Content
    content.Version:SetText(format("Version %s",GetAddOnMetadata("Classic Quest Log","Version")))

    for index,info in ipairs(optInfo) do
        if not content.CheckButtons[index] then
            content.CheckButtons[index] = CreateFrame("Button",nil,content,"ClassicQuestLogCheckButtonTemplate")
            content.CheckButtons[index]:SetPoint("TOPLEFT",content.CheckButtons[index-1],"BOTTOMLEFT")
            content.CheckButtons[index]:SetPoint("TOPRIGHT",content.CheckButtons[index-1],"BOTTOMRIGHT")
        end
        local checkButton = content.CheckButtons[index]
        checkButton.Text:SetText(info.text)
        checkButton.var = info.var
        checkButton.tooltipTitle = info.text
        checkButton.tooltipBody = info.desc
    end

    -- spacer at bottom of options so the last option isn't flush against the bottom
    content.Spacer = CreateFrame("Frame",nil,content)
    content.Spacer:SetSize(32,12)
    content.Spacer:SetPoint("TOPLEFT",content.CheckButtons[#optInfo],"BOTTOMLEFT")

    self:SetScript("OnSizeChanged",self.OnSizeChanged)
    self:OnSizeChanged(self:GetWidth(),self:GetHeight())

end

function cql.Options:Update()
    local content = self.ScrollFrame.Content

    if not self:IsVisible() then
        return
    end

    if cql.settings.HighContrast then
        self.Back:SetAtlas("QuestDetailsBackgrounds-Accessibility_Dark")
        self.Back:SetVertexColor(0.85,0.85,0.85)
    else
        self.Back:SetAtlas("QuestDetailsBackgrounds")
        self.Back:SetVertexColor(0.2,0.2,0.2)
    end

    for _,button in ipairs(content.CheckButtons) do
        button.CheckMark:SetShown(cql.settings[button.var] and true or false)
    end
end

function cql.Options:OnSizeChanged(width,height)
    local content = self.ScrollFrame.Content
    local contentWidth = max(floor(width+0.5)-35,150)
    content:SetWidth(contentWidth)

    content.Version:SetShown(contentWidth > (content.Title:GetStringWidth() + content.Version:GetStringWidth() + 20))

    for index,button in ipairs(content.CheckButtons) do
        button.Text:SetWidth(contentWidth-32-34)
        button:SetSize(contentWidth-32, max(30,button.Text:GetStringHeight())+2)
    end
end
